@@ -428,5 +428,5 @@ toList (Cons x xs) = x : toList xs
 -- /Beware/: Passing a finite list, will cause an error.
 fromList :: [a] -> Stream a
 fromList (x:xs) = Cons x (fromList xs)
-fromList []     = error "Stream.listToStream applied to finite list"
+fromList []     = error "Stream.fromList applied to finite list"
 
